@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -27,24 +27,12 @@ with DFILE Tools; see the file COPYING.  If not, see
 #include "dfile.h"
 #include "dfile_cache_create.h"
 
-static const char       rcsid[] = "$Id: smtable_readonly.c,v 1.2 2009/10/16 19:49:58 keith Exp $";
-
-/*
-** $Log: smtable_readonly.c,v $
-** Revision 1.2  2009/10/16 19:49:58  keith
-** Added GPL to source code.
-**
-** Revision 1.1  2009/03/03 06:59:05  keith
-** Initial revision
-**
-*/
 
 /*
 ** This fuction changes permission on shared memory segment to read only.
 */
 int smtable_readonly( int segment )
 {
-	static const char	func[] = "smtable_readonly";
 	struct shmid_ds shm_settings;
 
 	DEBUG_FUNC_START;
