@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -24,24 +24,12 @@ with DFILE Tools; see the file COPYING.  If not, see
 #include "dfile.h"
 #include "dfile_utility.h"
 
-static const char       rcsid[] = "$Id: compare_field_bind.c,v 1.2 2009/10/16 20:07:58 keith Exp $";
-
-/*
-** $Log: compare_field_bind.c,v $
-** Revision 1.2  2009/10/16 20:07:58  keith
-** Added GPL to source code.
-**
-** Revision 1.1  2009/03/08 06:17:34  keith
-** Initial revision
-**
-*/
 
 /*
 ** This function compares key fields between field and bind structures.
 */
 int compare_field_bind( const field_t *field, const dfile_bind_t **bind_key, unsigned short key_tbl_cnt )
 {
-	static const char	func[] = "compare_field_bind";
 	int	result;
 
 	assert( field != (const field_t *)0 );
