@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -25,24 +25,12 @@ with DFILE Tools; see the file COPYING.  If not, see
 #include "sexpr.h"
 #include "dfile_join.h"
 
-static const char       rcsid[] = "$Id: copy_record_to_bind.c,v 1.2 2009/10/16 20:07:58 keith Exp $";
-
-/*
-** $Log: copy_record_to_bind.c,v $
-** Revision 1.2  2009/10/16 20:07:58  keith
-** Added GPL to source code.
-**
-** Revision 1.1  2009/03/08 08:35:18  keith
-** Initial revision
-**
-*/
 
 /*
 ** This function copies a stored record to a bind structure.
 */
 void copy_record_to_bind( dfile_bind_t **bind, field_t *rec, unsigned short field_ndx_tbl_cnt )
 {
-	static const char	func[] = "copy_record_to_bind";
 	dfile_bind_t	*bind_ptr;
 
 	/*
