@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -25,24 +25,12 @@ with DFILE Tools; see the file COPYING.  If not, see
 #include "sexpr.h"
 #include "dfile_join.h"
 
-static const char       rcsid[] = "$Id: null_fields.c,v 1.2 2009/10/16 20:07:58 keith Exp $";
-
-/*
-** $Log: null_fields.c,v $
-** Revision 1.2  2009/10/16 20:07:58  keith
-** Added GPL to source code.
-**
-** Revision 1.1  2009/03/14 01:46:11  keith
-** Initial revision
-**
-*/
 
 /*
 ** This function nulls field values in a bind structure.
 */
 void null_fields( dfile_bind_t **bind, unsigned short field_ndx_tbl_cnt )
 {
-	static const char	func[] = "null_fields";
 	dfile_bind_t	*bind_ptr;
 
 	/*
