@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -23,17 +23,6 @@ with DFILE Tools; see the file COPYING.  If not, see
 #include "dfile.h"
 #include "dfile_partition.h"
 
-static const char       rcsid[] = "$Id: divvy_cmp.c,v 1.2 2009/10/16 20:16:47 keith Exp $";
-
-/*
-** $Log: divvy_cmp.c,v $
-** Revision 1.2  2009/10/16 20:16:47  keith
-** Added GPL to source code.
-**
-** Revision 1.1  2009/03/08 20:51:04  keith
-** Initial revision
-**
-*/
 
 /*
 ** This function is used for comparing partition values.
