@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -27,25 +27,12 @@ with DFILE Tools; see the file COPYING.  If not, see
 #include "sexpr.h"
 #include "dfile_sort.h"
 
-static const char       rcsid[] = "$Id: control_syntax_error.c,v 1.2 2009/10/16 20:22:24 keith Exp $";
-
-/*
-** $Log: control_syntax_error.c,v $
-** Revision 1.2  2009/10/16 20:22:24  keith
-** Added GPL to source code.
-**
-** Revision 1.1  2009/03/10 06:16:29  keith
-** Initial revision
-**
-*/
 
 /*
 ** This function outputs syntax error messages for control structure.
 */
 void control_syntax_error( const char *msg, const char *file, int line, unsigned short tuple )
 {
-	static const char	func[] = "control_syntax_error";
-
 	assert( msg != (const char *)0 );
 	assert( file != (const char *)0 );
 
