@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -27,24 +27,12 @@ with DFILE Tools; see the file COPYING.  If not, see
 #include "sexpr.h"
 #include "dfile_sort.h"
 
-static const char       rcsid[] = "$Id: copy_record_to_bind.c,v 1.2 2009/10/16 20:22:24 keith Exp $";
-
-/*
-** $Log: copy_record_to_bind.c,v $
-** Revision 1.2  2009/10/16 20:22:24  keith
-** Added GPL to source code.
-**
-** Revision 1.1  2009/03/10 06:18:21  keith
-** Initial revision
-**
-*/
 
 /*
 ** This function copies a sorted record to a bind structure.
 */
 void copy_record_to_bind( dfile_bind_t *bind, unsigned short bind_cnt, field_t *rec )
 {
-	static const char	func[] = "copy_record_to_bind";
 	field_t	*field;
 
 	assert( bind != (dfile_bind_t *)0 );
