@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -27,17 +27,6 @@ with DFILE Tools; see the file COPYING.  If not, see
 #include "sexpr.h"
 #include "dfile_sort.h"
 
-static const char       rcsid[] = "$Id: write_sorted_records.c,v 1.2 2009/10/16 20:22:24 keith Exp $";
-
-/*
-** $Log: write_sorted_records.c,v $
-** Revision 1.2  2009/10/16 20:22:24  keith
-** Added GPL to source code.
-**
-** Revision 1.1  2009/03/12 15:11:43  keith
-** Initial revision
-**
-*/
 
 /*
 ** This function writes sorted records. It is used when sorted data
@@ -45,7 +34,6 @@ static const char       rcsid[] = "$Id: write_sorted_records.c,v 1.2 2009/10/16
 */
 int write_sorted_records( dfile_t *dfile, field_t **record, unsigned long record_cnt )
 {
-	static const char	func[] = "write_sorted_records";
 	dfile_bind_t	*bind;
 	unsigned short	bind_cnt;
 
