@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -16,24 +16,12 @@ You should have received a copy of the GNU General Public License along
 with DFILE Tools; see the file COPYING.  If not, see
 <http://www.gnu.org/licenses/>. */
 
-/*
-**  $Id: dfile_dynamic.h,v 1.2 2009/10/16 16:53:52 keith Exp $
-**
-**
-**  $Log: dfile_dynamic.h,v $
-**  Revision 1.2  2009/10/16 16:53:52  keith
-**  Added GPL to source code.
-**
-**  Revision 1.1  2009/03/01 03:49:59  keith
-**  Initial revision
-**
-*/
 
-int map_dfile_field_names( unsigned short **, dfile_bind_t *, unsigned short, dfile_bind_t *, void * );
+int map_dfile_field_names( unsigned short **, dfile_bind_t *, unsigned short, dfile_bind_t *, dfile_bind_t **, unsigned short );
 
 int cmd_line_parse_tag( dfile_tag_t **, unsigned short *, char * );
 
-int assign_field_offset( unsigned short **, const char **, unsigned short, dfile_bind_t *, void * );
+int assign_field_offset( unsigned short **, char **, unsigned short, dfile_bind_t *, dfile_bind_t **, unsigned short );
 
 int compare_bind( const dfile_bind_t **, const dfile_bind_t **, unsigned short );
-int assign_field_bind( dfile_bind_t ***, const char **, unsigned short, void * );
+int assign_field_bind( dfile_bind_t ***, char **, unsigned short, dfile_bind_t **, unsigned short );
