@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -16,17 +16,6 @@ You should have received a copy of the GNU General Public License along
 with DFILE Tools; see the file COPYING.  If not, see
 <http://www.gnu.org/licenses/>. */
 
-/*
-**  $Id: dfile_utility.h,v 1.2 2009/10/16 17:02:35 keith Exp $
-**
-** $Log: dfile_utility.h,v $
-** Revision 1.2  2009/10/16 17:02:35  keith
-** Added GPL to source code.
-**
-** Revision 1.1  2009/03/01 06:14:04  keith
-** Initial revision
-**
-*/
 
 typedef struct {
 	char	*value;
@@ -43,4 +32,4 @@ size_t sum_field_length( const dfile_bind_t *, unsigned short );
 
 int alloc_record_key( field_t ***, size_t );
 
-int format_hash_values( const char ***, unsigned short );
+int format_hash_values( char ***, unsigned short );
