@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -24,17 +24,6 @@ with DFILE Tools; see the file COPYING.  If not, see
 #include "dfile.h"
 #include "_dfile.h"
 
-static const char       rcsid[] = "$Id: _dfile_overflow.c,v 1.2 2009/10/16 07:35:55 keith Exp $";
-
-/*
-** $Log: _dfile_overflow.c,v $
-** Revision 1.2  2009/10/16 07:35:55  keith
-** Add GPL to source code.
-**
-** Revision 1.1  2009/02/25 07:59:38  keith
-** Initial revision
-**
-*/
 
 /*
 ** This function finds the beginning of the last record fragment in buffer.
@@ -42,7 +31,6 @@ static const char       rcsid[] = "$Id: _dfile_overflow.c,v 1.2 2009/10/16 07:35
 
 int _dfile_overflow( const char **buf_ptr_end, const char *buffer, size_t buffer_len, dfile_rec_t rec )
 {
-	static const char	func[] = "_dfile_overflow";
 	register const char	*ptr;
 
 	assert( buf_ptr_end != (const char **)0 );
