@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -23,17 +23,6 @@ with DFILE Tools; see the file COPYING.  If not, see
 #include "dfile.h"
 #include "_dfile.h"
 
-static const char       rcsid[] = "$Id: _dfile_parse_registry_field.c,v 1.2 2009/10/16 07:35:55 keith Exp $";
-
-/*
-** $Log: _dfile_parse_registry_field.c,v $
-** Revision 1.2  2009/10/16 07:35:55  keith
-** Add GPL to source code.
-**
-** Revision 1.1  2009/02/26 07:29:32  keith
-** Initial revision
-**
-*/
 
 /*
 ** This function parses field name from record layout line of text. End of
@@ -42,7 +31,6 @@ static const char       rcsid[] = "$Id: _dfile_parse_registry_field.c,v 1.2 2009
 
 int _dfile_parse_registry_field( char **rec )
 {
-	static const char	func[] = "_dfile_parse_registry_field";
 	register char	*ptr;
 
 	assert( rec != (char **)0 );
@@ -56,7 +44,6 @@ int _dfile_parse_registry_field( char **rec )
 		if ( isspace( *ptr ) ) {
 			break;
 		}
-		*ptr = toupper( *ptr );
 		++ptr;
 	}
 
