@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -24,20 +24,6 @@ with DFILE Tools; see the file COPYING.  If not, see
 #include "dfile.h"
 #include "_dfile.h"
 
-static const char       rcsid[] = "$Id: _dfile_release_buffer.c,v 1.3 2009/10/16 07:35:56 keith Exp $";
-
-/*
-** $Log: _dfile_release_buffer.c,v $
-** Revision 1.3  2009/10/16 07:35:56  keith
-** Add GPL to source code.
-**
-** Revision 1.2  2009/05/21 20:58:39  keith
-** Made changes to use DFILE_THREAD as compile time switch for threading.
-**
-** Revision 1.1  2009/02/28 03:03:17  keith
-** Initial revision
-**
-*/
 
 #ifdef DFILE_THREAD
 
@@ -47,7 +33,6 @@ static const char       rcsid[] = "$Id: _dfile_release_buffer.c,v 1.3 2009/10/16
 
 int _dfile_release_buffer( dfile_buffer_t *buffer )
 {
-	static const char	func[] = "_dfile_release_buffer";
 	int	ret;
 
 	assert( buffer != (dfile_buffer_t *)0 );
