@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -23,17 +23,6 @@ with DFILE Tools; see the file COPYING.  If not, see
 #include "dfile.h"
 #include "_dfile.h"
 
-static const char       rcsid[] = "$Id: _dfile_resize_overflow.c,v 1.2 2009/10/16 07:35:56 keith Exp $";
-
-/*
-** $Log: _dfile_resize_overflow.c,v $
-** Revision 1.2  2009/10/16 07:35:56  keith
-** Add GPL to source code.
-**
-** Revision 1.1  2009/02/28 03:29:22  keith
-** Initial revision
-**
-*/
 
 /*
 ** This function resizes overflow memory when necessary.
@@ -41,7 +30,6 @@ static const char       rcsid[] = "$Id: _dfile_resize_overflow.c,v 1.2 2009/10/1
 
 int _dfile_resize_overflow( char **overflow, size_t *overflow_size, size_t required_size )
 {
-	static const char	func[] = "_dfile_resize_overflow";
 	const size_t	minimum_size = 500;
 	char	*new;
 
