@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -23,17 +23,6 @@ with DFILE Tools; see the file COPYING.  If not, see
 #include "dfile.h"
 #include "_dfile.h"
 
-static const char       rcsid[] = "$Id: _dfile_skip_spaces.c,v 1.2 2009/10/16 07:35:56 keith Exp $";
-
-/*
-** $Log: _dfile_skip_spaces.c,v $
-** Revision 1.2  2009/10/16 07:35:56  keith
-** Add GPL to source code.
-**
-** Revision 1.1  2009/02/28 04:12:59  keith
-** Initial revision
-**
-*/
 
 /*
 ** This function is used to parse registry records. It skips over white spaces
@@ -42,7 +31,6 @@ static const char       rcsid[] = "$Id: _dfile_skip_spaces.c,v 1.2 2009/10/16 07
 
 int _dfile_skip_spaces( char **rec )
 {
-	static const char	func[] = "_dfile_skip_spaces";
 
 	assert( rec != (char **)0 );
 	assert( *rec != (char *)0 );
