@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -23,17 +23,6 @@ with DFILE Tools; see the file COPYING.  If not, see
 #include "dfile.h"
 #include "_dfile.h"
 
-static const char       rcsid[] = "$Id: dfile_bind_field_name_cmp.c,v 1.2 2009/10/16 07:35:52 keith Exp $";
-
-/*
-** $Log: dfile_bind_field_name_cmp.c,v $
-** Revision 1.2  2009/10/16 07:35:52  keith
-** Add GPL to source code.
-**
-** Revision 1.1  2009/02/28 18:41:28  keith
-** Initial revision
-**
-*/
 
 /*
 ** This function is used to compare dfile_bind_t structures by field_name.
@@ -41,10 +30,19 @@ static const char       rcsid[] = "$Id: dfile_bind_field_name_cmp.c,v 1.2 2009/1
 
 int dfile_bind_field_name_cmp( const void *x, const void *y )
 {
+	const dfile_bind_t	*lhs, *rhs;
+
 	assert( x != (const void *)0 );
 	assert( y != (const void *)0 );
+
+	lhs = *(const dfile_bind_t **)x;
+	rhs = *(const dfile_bind_t **)y;
+
+	assert( lhs != (const dfile_bind_t *)0 );
+	assert( rhs != (const dfile_bind_t *)0 );
+
 	assert( ( (const dfile_bind_t *)x )->field_name != (const char *)0 );
 	assert( ( (const dfile_bind_t *)y )->field_name != (const char *)0 );
 
-	return strcmp( ( (const dfile_bind_t *)x )->field_name, ( (const dfile_bind_t *)y )->field_name );
+	return strcasecmp( lhs->field_name, rhs->field_name );
 }
