@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -23,24 +23,12 @@ with DFILE Tools; see the file COPYING.  If not, see
 #include "dfile.h"
 #include "dfile_utility.h"
 
-static const char       rcsid[] = "$Id: alloc_record_key.c,v 1.2 2009/10/16 17:02:35 keith Exp $";
-
-/*
-** $Log: alloc_record_key.c,v $
-** Revision 1.2  2009/10/16 17:02:35  keith
-** Added GPL to source code.
-**
-** Revision 1.1  2009/03/01 05:17:59  keith
-** Initial revision
-**
-*/
 
 /*
 ** This function allocates an address pointers for record key.
 */
 int alloc_record_key( field_t ***rec_key, size_t key_cnt )
 {
-	static const char	func[] = "alloc_record_key";
 	size_t	alloc_size;
 	field_t	**new;
 
