@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -23,24 +23,12 @@ with DFILE Tools; see the file COPYING.  If not, see
 #include "dfile.h"
 #include "dfile_utility.h"
 
-static const char       rcsid[] = "$Id: free_record.c,v 1.2 2009/10/16 17:02:35 keith Exp $";
-
-/*
-** $Log: free_record.c,v $
-** Revision 1.2  2009/10/16 17:02:35  keith
-** Added GPL to source code.
-**
-** Revision 1.1  2009/03/01 05:57:04  keith
-** Initial revision
-**
-*/
 
 /*
 ** This function frees memory containing temporary field values.
 */
 void free_record( field_t **rec, unsigned long rec_cnt )
 {
-	static const char	func[] = "free_record";
 	field_t	**ptr, *field;
 
 	assert( rec != (field_t **)0 );
