@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -24,24 +24,12 @@ with DFILE Tools; see the file COPYING.  If not, see
 #include "dfile.h"
 #include "dfile_utility.h"
 
-static const char       rcsid[] = "$Id: sum_field_length.c,v 1.2 2009/10/16 17:02:35 keith Exp $";
-
-/*
-** $Log: sum_field_length.c,v $
-** Revision 1.2  2009/10/16 17:02:35  keith
-** Added GPL to source code.
-**
-** Revision 1.1  2009/03/01 06:08:44  keith
-** Initial revision
-**
-*/
 
 /*
 ** This function sums field lengths.
 */
 size_t sum_field_length( const dfile_bind_t *bind, unsigned short bind_cnt )
 {
-	static const char	func[] = "sum_field_length";
 	static const char	end_msg[] = "End %s() returning %u at %s\n";
 	size_t	record_size;
 
@@ -61,7 +49,7 @@ size_t sum_field_length( const dfile_bind_t *bind, unsigned short bind_cnt )
 	}
 
 	if ( Debug ) {
-		(void) fprintf( stderr, end_msg, func, record_size, get_ctime() );
+		(void) fprintf( stderr, end_msg, __func__, record_size, get_ctime() );
 	}
 
 	return record_size;
