@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -19,17 +19,6 @@ with DFILE Tools; see the file COPYING.  If not, see
 #include "stddef.h"
 #include "sexpr.h"
 
-static const char       rcsid[] = "$Id: _sexpr_global.c,v 1.2 2009/10/16 17:11:40 keith Exp $";
-
-/*
-** $Log: _sexpr_global.c,v $
-** Revision 1.2  2009/10/16 17:11:40  keith
-** Added GPL to source code.
-**
-** Revision 1.1  2009/02/15 09:10:21  keith
-** Initial revision
-**
-*/
 
 const char *Sexpr_err_msg[] = {
 
