@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -23,17 +23,6 @@ with DFILE Tools; see the file COPYING.  If not, see
 #include "tbox.h"
 #include "sexpr.h"
 
-static const char       rcsid[] = "$Id: sexpr_error.c,v 1.2 2009/10/16 17:11:40 keith Exp $";
-
-/*
-** $Log: sexpr_error.c,v $
-** Revision 1.2  2009/10/16 17:11:40  keith
-** Added GPL to source code.
-**
-** Revision 1.1  2009/02/15 09:12:48  keith
-** Initial revision
-**
-*/
 
 /*
 ** This function formats an error message.
@@ -41,7 +30,6 @@ static const char       rcsid[] = "$Id: sexpr_error.c,v 1.2 2009/10/16 17:11:40
 
 const char *sexpr_error( int sexpr_errno )
 {
-	static const char func[] = "sexpr_error";
 	static const char	unknown_msg[] = "unknown error";
 	const char	*ret;
 
