@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -23,18 +23,6 @@ with DFILE Tools; see the file COPYING.  If not, see
 #include <limits.h>
 #include "tbox.h"
 
-static const char       rcsid[] = "$Id: dhsearch.c,v 1.2 2009/10/16 18:00:43 keith Exp $";
-
-/*
-** $Log: dhsearch.c,v $
-** Revision 1.2  2009/10/16 18:00:43  keith
-** Added GPL to source code.
-**
-** Revision 1.1  2009/02/14 09:12:23  keith
-** Initial revision
-**
-*/
-
 /*
 ** The hashing algorithm used in this module is an implementation of
 ** Knuth's 6.4 Algorithm D from 'The Art of Computer Programming,
@@ -71,7 +59,6 @@ typedef struct {
 */
 void *dhcreate( unsigned long buckets, unsigned long allowed_collisions )
 {
-	static const char	func[] = "dhcreate";
 	htable_header_t	*header;
 	size_t	alloc_size;
 	void	*ptr;
@@ -157,7 +144,6 @@ void *dhcreate( unsigned long buckets, unsigned long allowed_collisions )
 */
 void *dhsearch( const void *data, void *arena, unsigned long ( *calc_key )( const void * ), int ( *key_cmp )( const void *, const void * ) )
 {
-	static const char	func[] = "dhsearch";
 	htable_header_t	*header;
 	unsigned long	key, ndx, delta_ndx, total_buckets;
 	unsigned long	collision_cnt, *ndx_tbl = 0;
@@ -457,7 +443,6 @@ static int greater_collision( const void **bucket, unsigned long ndx, unsigned l
 */
 void *dhfind( const void *data, const void *arena, unsigned long key, int ( *key_cmp )( const void *, const void * ) )
 {
-	static const char	func[] = "dhfind";
 	htable_header_t	*header;
 	unsigned long	ndx, delta_ndx, total_buckets;
 	unsigned long	collision_cnt;
@@ -544,7 +529,6 @@ void *dhfind( const void *data, const void *arena, unsigned long key, int ( *key
 */
 void *dhdelete( const void *data, const void *arena, unsigned long key, int ( *key_cmp )( const void *, const void * ) )
 {
-	static const char	func[] = "dhdelete";
 	void	**bucket, *existing_data;
 
 	assert( arena != (void *)0 );
@@ -572,7 +556,6 @@ void *dhdelete( const void *data, const void *arena, unsigned long key, int ( *k
 */
 void *dhesearch( const void *data, void **arena, unsigned long ( *calc_key )( const void * ), int ( *key_cmp )( const void *, const void * ) )
 {
-	static const char	func[] = "dhesearch";
 	htable_header_t	*old_header, *new_header;
 	void 	*ptr, *new_hash;
 	unsigned short	expansion_cnt;
