@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -20,18 +20,6 @@ with DFILE Tools; see the file COPYING.  If not, see
 #include <time.h>
 #include "tbox.h"
 
-static const char       rcsid[] = "$Id: fmt_ctime.c,v 1.2 2009/10/16 18:00:43 keith Exp $";
-
-/*
-** $Log: fmt_ctime.c,v $
-** Revision 1.2  2009/10/16 18:00:43  keith
-** Added GPL to source code.
-**
-** Revision 1.1  2009/02/14 09:15:09  keith
-** Initial revision
-**
-*/
-
 /*
 ** This function returns the address of a string containing the current
 ** time in the format MM/DD/YY HH:MM:SS.
