@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -19,18 +19,6 @@ with DFILE Tools; see the file COPYING.  If not, see
 #include <stdio.h>
 #include "tbox.h"
 
-static const char       rcsid[] = "$Id: get_ctime.c,v 1.2 2009/10/16 18:00:43 keith Exp $";
-
-/*
-** $Log: get_ctime.c,v $
-** Revision 1.2  2009/10/16 18:00:43  keith
-** Added GPL to source code.
-**
-** Revision 1.1  2009/02/14 09:17:24  keith
-** Initial revision
-**
-*/
-
 /*
 ** This is a wrapper function for fmt_ctime().
 */
