@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -16,21 +16,6 @@ You should have received a copy of the GNU General Public License along
 with DFILE Tools; see the file COPYING.  If not, see
 <http://www.gnu.org/licenses/>. */
 
-static const char       rcsid[] = "$Id: global.c,v 1.3 2009/10/16 18:00:43 keith Exp $";
-
-/*
-** $Log: global.c,v $
-** Revision 1.3  2009/10/16 18:00:43  keith
-** Added GPL to source code.
-**
-** Revision 1.2  2009/03/18 00:46:29  keith
-** Added checks for NDEBUG macro.
-**
-** Revision 1.1  2009/02/14 09:19:21  keith
-** Initial revision
-**
-*/
-
 #ifndef NDEBUG
 int		Debug;
 
