@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -23,17 +23,6 @@ with DFILE Tools; see the file COPYING.  If not, see
 #include "tbox.h"
 #include "rbtree.h"
 
-static const char       rcsid[] = "$Id: rbtree.c,v 1.2 2009/10/16 18:00:43 keith Exp $";
-
-/*
-** $Log: rbtree.c,v $
-** Revision 1.2  2009/10/16 18:00:43  keith
-** Added GPL to source code.
-**
-** Revision 1.1  2009/02/14 21:35:29  keith
-** Initial revision
-**
-*/
 
 /*
 ** The tree routines in this module, rbtsearch(), rbtfind(), rbtwalk() and
@@ -109,7 +98,6 @@ static rbtree_t *tree_minimum( rbtree_t * );
 */
 void *rbtsearch( void *datum, void **r, int (*compar)( const void *, const void * ) )
 {
-	static const char	func[] = "rbtsearch";
 	register rbtree_t	*node;
 	register rbtree_t	*parent = &null_node;
 	rbtree_t	**root = (rbtree_t **) r;
@@ -351,8 +339,6 @@ struct mallinfo	minfo;
 */
 void rbtwalk( const void *root, void (*action)( const void *, VISIT, int ) )
 {
-	static const char	func[] = "rbtwalk";
-
 	assert( action != (void (*)( const void *, VISIT, int )) 0 );
 
 	DEBUG_FUNC_START;
@@ -408,7 +394,6 @@ printf( "%s, %s\n", (char *)node->datum, node->color == Red ? "RED" : "BLACK" );
 */
 void *rbtdelete( const void *datum, void **r, int (*compar)( const void *, const void * ) )
 {
-	static const char	func[] = "rbtdelete";
 	register rbtree_t	*node, *sibling, *parent;
 	rbtree_t	**root = (rbtree_t **) r;
 	rbtree_t	*splice_out, *child;
@@ -722,7 +707,6 @@ struct mallinfo	minfo;
 */
 void rbtfree( void **r, void (*free_datum)( void * ) )
 {
-	static const char	func[] = "rbtfree";
 	register rbtree_t	*node, *parent;
 	rbtree_t	**root = (rbtree_t **) r;
 #if 0
@@ -792,7 +776,6 @@ struct mallinfo	minfo;
 */
 void *rbtfind( const void *datum, void * const *root, int (*compar)( const void *, const void * ) )
 {
-	static const char	func[] = "rbtfind";
 	register const rbtree_t	*node;
 	int	compar_value;
 
