@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -21,17 +21,6 @@ with DFILE Tools; see the file COPYING.  If not, see
 #include <assert.h>
 #include "tbox.h"
 
-static const char       rcsid[] = "$Id: strnncmp.c,v 1.2 2009/10/16 18:00:43 keith Exp $";
-
-/*
-** $Log: strnncmp.c,v $
-** Revision 1.2  2009/10/16 18:00:43  keith
-** Added GPL to source code.
-**
-** Revision 1.1  2009/02/15 02:56:44  keith
-** Initial revision
-**
-*/
 
 /*
 ** This function compares two strings having both lengths available.
@@ -39,7 +28,6 @@ static const char       rcsid[] = "$Id: strnncmp.c,v 1.2 2009/10/16 18:00:43 kei
 
 int strnncmp( const char *lhs_str, size_t lhs_len, const char *rhs_str, size_t rhs_len )
 {
-	static const char func[] = "strnncmp";
 	size_t	cmp_len;
 	int	result;
 
@@ -47,7 +35,7 @@ int strnncmp( const char *lhs_str, size_t lhs_len, const char *rhs_str, size_t r
 	assert( rhs_str != (const char *)0 );
 
 	if ( Debug ) {
-		(void) fprintf( stderr, "%s( [%s], %u, [%s], %u )\n", func, lhs_str, lhs_len, rhs_str, rhs_len );
+		(void) fprintf( stderr, "%s( [%s], %u, [%s], %u )\n", __func__, lhs_str, lhs_len, rhs_str, rhs_len );
 	}
 
 	DEBUG_FUNC_START;
