@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -21,17 +21,6 @@ with DFILE Tools; see the file COPYING.  If not, see
 #include <assert.h>
 #include "tbox.h"
 
-static const char       rcsid[] = "$Id: strtoupper.c,v 1.2 2009/10/16 18:00:43 keith Exp $";
-
-/*
-** $Log: strtoupper.c,v $
-** Revision 1.2  2009/10/16 18:00:43  keith
-** Added GPL to source code.
-**
-** Revision 1.1  2009/02/15 03:01:10  keith
-** Initial revision
-**
-*/
 
 /*
 ** This function converts a string to upper case.
@@ -39,12 +28,10 @@ static const char       rcsid[] = "$Id: strtoupper.c,v 1.2 2009/10/16 18:00:43 k
 
 void strtoupper( register char *str )
 {
-	static const char func[] = "strtoupper";
-
 	assert( str != (char *)0 );
 
 	if ( Debug ) {
-		(void) fprintf( stderr, "%s( %s )\n", func, str );
+		(void) fprintf( stderr, "%s( %s )\n", __func__, str );
 	}
 
 	DEBUG_FUNC_START;
