@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -21,17 +21,6 @@ with DFILE Tools; see the file COPYING.  If not, see
 #include "dfile.h"
 #include "where.h"
 
-static const char       rcsid[] = "$Id: _where_global.c,v 1.2 2009/10/16 17:27:11 keith Exp $";
-
-/*
-** $Log: _where_global.c,v $
-** Revision 1.2  2009/10/16 17:27:11  keith
-** Added GPL to source code.
-**
-** Revision 1.1  2009/02/18 05:33:40  keith
-** Initial revision
-**
-*/
 
 const char *Where_err_msg[] = {
 
