@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -25,17 +25,6 @@ with DFILE Tools; see the file COPYING.  If not, see
 #include "where.h"
 #include "_where.h"
 
-static const char       rcsid[] = "$Id: where_condition.c,v 1.2 2009/10/16 17:27:11 keith Exp $";
-
-/*
-** $Log: where_condition.c,v $
-** Revision 1.2  2009/10/16 17:27:11  keith
-** Added GPL to source code.
-**
-** Revision 1.1  2009/02/18 06:21:42  keith
-** Initial revision
-**
-*/
 
 /*
 ** This is a wrapper function for _where_condition. It executes the filter
@@ -44,7 +33,6 @@ static const char       rcsid[] = "$Id: where_condition.c,v 1.2 2009/10/16 17:27
 
 int where_condition( where_result_t *result, char *err_msg, size_t err_msg_size, void *condition )
 {
-	static const char func[] = "where_condition";
 	int	ret;
 
 	assert( result != (where_result_t *)0 );
