@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Keith Crane
+/* Copyright (C) 2009, 2010, 2011 Keith Crane
 
 This file is part DFILE Tools.
 
@@ -24,17 +24,6 @@ with DFILE Tools; see the file COPYING.  If not, see
 #include "dfile.h"
 #include "where.h"
 
-static const char       rcsid[] = "$Id: where_error.c,v 1.2 2009/10/16 17:27:11 keith Exp $";
-
-/*
-** $Log: where_error.c,v $
-** Revision 1.2  2009/10/16 17:27:11  keith
-** Added GPL to source code.
-**
-** Revision 1.1  2009/02/18 06:22:40  keith
-** Initial revision
-**
-*/
 
 /*
 ** This function formats an error message.
@@ -42,7 +31,6 @@ static const char       rcsid[] = "$Id: where_error.c,v 1.2 2009/10/16 17:27:11
 
 const char *where_error( int where_errno )
 {
-	static const char func[] = "where_error";
 	static const char	unknown_msg[] = "unknown error";
 	const char	*ret;
 
